#!/bin/sh
# Begin of libpretty.sh

#
#
#
#
# - print_status
#
#
#



# INCLUDE
include color

#
# === Begin Code
#

Title()
{
	usage_string="usage: $FUNCNAME {string}"

        if test "$#" = "0"
        then
                echo $usage_string
                return 1
        fi

	echo -e "\n\n${WHITE}    $*${NORMAL}\n"
}

Section()
{
	usage_string="usage: $FUNCNAME {string}"

        if test "$#" = "0"
        then
                echo $usage_string
                return 1
        fi

	echo -e "\n${WHITE}$*${NORMAL}"
};

Elt()
{
	usage_string="usage: $FUNCNAME {string}"

        if test "$#" = "0"
        then
                echo $usage_string
                return 1
        fi

	echo -n " - $*${NORMAL}"
}

Feedback()
{
    errorlevel="$?"

    usage_string="usage: $FUNCNAME [{fail-label} [{ok-label}  [{fail-string} [{ok-string}]]]]"

    if test "$#" -gt "5"
    then
	echo $usage_string
	return 1
    fi


    if test "$errorlevel" = "0" ; then
	test  "$4" && print_info "$4"
	test  "$4" && print_status "$2" || print_status success
    else
	test  "$3" && print_info "$3"
	test  "$1" && print_status "$1" || print_status failure
    fi

    return $errorlevel
}


print_info()
{
	usage_string="usage: $FUNCNAME {string}"

        if test "$#" = "0" 
        then
                echo $usage_string
                return 1
        fi

	echo -n "${SET_WCOL}${GRAY}$*${NORMAL}"

};

print_info_char()
{
    usage_string="usage: $FUNCNAME {string}"
    
    if test "$#" = "0" 
    then
	echo $usage_string
	return 1
    fi
    char=$(echo $* | cut -c 1)

    echo -n "${SET_LCOL}${WHITE}$char${NORMAL}"
    
};

set_col()
{

    usage_string="usage: $FUNCNAME {number}"

    if test "$#" != "1" 
    then
	echo $usage_string
	return 1
    fi

    echo -en "\\033[${1}G";

};


print_status()
{

	usage_string="usage: $FUNCNAME {success|warning|failure|on|off|noop} {short|long} {string}"


        if test "$#" = "0"
        then
                echo $usage_string
                return 1
        fi


        if test "$2" != "short" && test "$2" != "long" && test "$#" != "1"
        then
		echo "$FUNCNAME: '$2' is a bad second argument, try : short long"
                echo $usage_string
                return 1
        fi


	type_method=$2

	if  test "$#" = "1"  
	then
	    type_method="long"
	fi


        case "$1" in
                success)
			if test "$type_method" = "long" 
			then
			    echo -n "${SET_COL}["
			    echo -n "${SUCCESS}"
			    echo -n "  OK  "
			    echo "${NORMAL}]"
			else
			    echo -n "${SUCCESS}"
			    shift; shift;
			    echo -n "$*${NORMAL}"
			fi
                        ;;
                warning)
			if test "$type_method" = "long" 
			then
			    echo -n "${SET_COL}["
			    echo -n "${WARNING}"
			    echo -n " ATTN "
			    echo "${NORMAL}]"
			else
			    echo -n "${WARNING}"
			    shift; shift;
			    echo -n "$*${NORMAL}"
			fi
                        ;;
                failure)
			if test "$type_method" = "long" 
			then
			    echo -n "${SET_COL}["
			    echo -n "${FAILURE}"
			    echo -n "FAILED"
			    echo "${NORMAL}]"
			else
			    echo -n "${FAILURE}"
			    shift; shift;
			    echo -n "$*${NORMAL}"
			fi
                        ;;
		on)
			if test "$type_method" = "long" 
			then
			    echo -n "${SET_COL}["
			    echo -n "${ON}"
			    echo -n "  ON  "
			    echo "${NORMAL}]"
			else
			    echo -n "${ON}"
			    shift; shift;
			    echo -n "$*${NORMAL}"
			fi
			;;
		off)
			if test "$type_method" = "long" 
			then
			    echo -n "${SET_COL}["
			    echo -n "${OFF}"
			    echo -n "  OFF "
			    echo "${NORMAL}]"
			else
			    echo -n "${OFF}"
			    shift; shift;
			    echo -n "$*${NORMAL}"
			fi
			;;
		noop)
			if test "$type_method" = "long" 
			then
			    echo -n "${SET_COL}["
			    echo -n "${NOOP}"
			    echo -n "  NA  "
			    echo "${NORMAL}]"
			else
			    echo -n "${NOOP}"
			    shift; shift;
			    echo -n "$*${NORMAL}"
			fi
			;;


	        *)
			echo "$FUNCNAME: '$1' is a bad first argument."
        	        echo $usage_string
	                return 1
			;;

        esac

}


# End of libpretty.sh
